/*
 * Copyright (c) 2011, Disgruntled Rats
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   - Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *
 *   - Redistributions in binary form must reproduce the above copyright notice,
 *     this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 *   - Neither the name of the Disgruntled Rats nor the names of its
 *     contributors may be used to endorse or promote products derived from
 *     this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 */

package com.disgruntledrats;

import java.util.HashMap;
import java.util.Map;

import android.os.AsyncTask;
import android.os.Bundle;
import android.widget.TextView;

import com.disgruntledrats.billing.android.AndroidMarketAccount;
import com.disgruntledrats.item.DisposableItem;
import com.disgruntledrats.item.PermanentItem;
import com.disgruntledrats.item.Safe;
import com.disgruntledrats.item.Store;

/**
 * A sample application that demonstrates in-app billing.
 */
public class ApplicationActivity extends BillingActivity {

    private static final Store STORE = Store.getInstance();
    private static final Safe SAFE = Safe.getInstance();
    private static final Map<String, PermanentItem> permanentItemIds;
    private static final Map<String, DisposableItem> disposableItemIds;

    private static final String PRODUCT_1 = "android.test.purchased";
    private static final double PRODUCT_1_COST = 1;

    TextView textView;

    public ApplicationActivity() {
        // Add your AndroidMarketAccount information here.
        account = new AndroidMarketAccount() {
             /*
              * (non-Javadoc)
              * @see com.disgruntledrats.account.AndroidMarketAccount#getPublicKey()
              */
             @Override
             public String getPublicKey() {
                 return "<insert your public key from your google market account here>";
             }
         };
    }

    static {
        permanentItemIds = new HashMap<String, PermanentItem>();
        PermanentItem permanentItem
            = new PermanentItem(PRODUCT_1, PRODUCT_1_COST);
        permanentItemIds.put(permanentItem.getId(), permanentItem);
        disposableItemIds = new HashMap<String, DisposableItem>();
    }

    /*
     * (non-Javadoc)
     * @see android.app.Activity#onCreate(android.os.Bundle)
     */
    @Override
    public void onCreate(Bundle savedInstanceState) {
       super.onCreate(savedInstanceState);
       STORE.initialize(this, disposableItemIds, permanentItemIds);
       textView = new TextView(this);
       setContentView(textView);
       textView.setText("Starting application...\n");

       // check to see if the store is open
       if (STORE.isOpen()) {
           textView.append("Store is open.\n");
       } else {
           textView.append("Store is closed.\n");
           return;
       }
       // we are making a purchase by default
       textView.append("Purchasing " + PRODUCT_1 + '\n');
       if(STORE.purchase(PRODUCT_1)) {
           textView.append("Purchased request sent " + PRODUCT_1 + " successfully.");
       } else {
           textView.append("Could not purchase " + PRODUCT_1 + ".");
       }
       /*
        *  starting a new thread to run for a while and look for changes to the
        *  store.
        */
       new TextViewThread().execute();
    }

    /*
     * (non-Javadoc)
     * @see android.app.Activity#onDestroy()
     */
    @Override
    protected void onDestroy() {
        super.onDestroy();
        STORE.close();
    }

    /**
     * Simple thread for updating the UI when the safe contents change
     */
    private class TextViewThread extends AsyncTask {

        // only printing something if the safe changes
        private String previousSafeValue;

        /*
         * (non-Javadoc)
         * @see android.os.AsyncTask#doInBackground(Params[])
         */
        @Override
        protected Object doInBackground(Object... arg0) {

            for (int i = 0; i < 60; i++){
                try {
                    Thread.sleep(1000);
                } catch (InterruptedException e) {
                 e.printStackTrace();
                }
                publishProgress();
            }
            System.exit(1);
            return null;
        }

        /*
         * (non-Javadoc)
         * @see android.os.AsyncTask#onProgressUpdate(Progress[])
         */
        @Override
        protected void onProgressUpdate(Object... values) {
            if (!SAFE.toString().equals(previousSafeValue)) {
                String newSafeString = SAFE.toString();
                textView.append(newSafeString + '\n');
                previousSafeValue = newSafeString;
            }
        }
    }
}
