/*
 * Copyright (c) 2011, Disgruntled Rats
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   - Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *
 *   - Redistributions in binary form must reproduce the above copyright notice,
 *     this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 *   - Neither the name of the Disgruntled Rats nor the names of its
 *     contributors may be used to endorse or promote products derived from
 *     this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 */

package com.disgruntledrats.billing.android;

/**
 * Each application will need to implement one of these.  The purpose of this
 * is to only keep the public key in memory for a short period of time.
 * Honestly, I don't think this is going to help anyone who is getting their
 * application hacked.
 * 
 * I had to put this class with the other billing classes to hide the methods
 * from callers external to this package.
 */
public abstract class AndroidMarketAccount {

    /**
     * Gets the public key for your Android Market Account.
     * 
     * Here are the steps to obtain your key.
     * 1. Log in to your Android Market publisher account.
     * 2. On the upper left part of the page, under your name, click Edit Profile.
     * 3. On the Edit Profile page, scroll down to the Licensing & In-app Billing panel.
     * 4. Copy your public key.
     * 
     * WARNING: Do not keep a reference to this key in a local variable.
     * Return a new String instance.
     * @return
     *          the public key for your Android Market Account.
     */
    protected abstract String getPublicKey();
}
