/*
 * Copyright (c) 2011, Disgruntled Rats
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   - Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *
 *   - Redistributions in binary form must reproduce the above copyright notice,
 *     this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 *   - Neither the name of the Disgruntled Rats nor the names of its
 *     contributors may be used to endorse or promote products derived from
 *     this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 */

package com.disgruntledrats.store;

import java.util.List;

import org.junit.Test;

import com.disgruntledrats.item.Item;
import com.disgruntledrats.item.Safe;

import junit.framework.TestCase;

public class SafeTest extends TestCase {

    private static final Safe SAFE = Safe.getInstance();

    @Test
    public void testAddItemOneItem() {
        String itemId = "widget1";
        Item item = new Item(itemId, 1);
        SAFE.addItem(item);
        List<Item> items = SAFE.getItems(itemId);
        assertEquals(1, items.size());
        Item returnItem = items.get(0);
        assertEquals(item, returnItem);
        SAFE.clear();
    }

    @Test
    public void testRemoveItemOneItem() {
        String itemId = "widget1";
        Item item = new Item(itemId, 1);
        SAFE.addItem(item);
        SAFE.removeItem(itemId);
        List<Item> items = SAFE.getItems(itemId);
        assertNull(items);
        SAFE.clear();
    }

    @Test
    public void testToString() {
        String itemId = "widget1";
        Item item = new Item(itemId, 1);
        SAFE.addItem(item);
        assertNotNull(SAFE.toString());
    }

}
